@@ -15,6 +15,7 @@ class TestGI(unittest.TestCase):
     def test_method(self):
         '''GLib method call'''
 
-        self.assertEqual(GLib.find_program_in_path('bash'), '/bin/bash')
+        self.assertIn(GLib.find_program_in_path('bash'), ('/bin/bash', '/usr/bin/bash'))
+
 
 unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout, verbosity=2))
